@@ -240,6 +240,7 @@ class Const(NestedDeclarator):
 
 class Extern(DeclSpecifier):
     def __init__(self, language, subdecl):
+        self.language = language
         super(Extern, self).__init__(subdecl, "extern \"%s\"" % language)
 
     mapper_method = "map_extern"
@@ -614,7 +615,8 @@ class If(Generable):
         self.else_ = else_
 
     def generate(self):
-        condition_lines = self.condition.split("\n")
+        cond_str = str(self.condition)
+        condition_lines = cond_str.split("\n")
         if len(condition_lines) > 1:
             yield "if ("
             for l in condition_lines:
@@ -676,6 +678,8 @@ class CustomLoop(Loop):
     def outro_line(self):
         return self.outro_line_
 
+    mapper_method = "map_custom_loop"
+
 
 class While(Loop):
     def __init__(self, condition, body):
@@ -783,7 +787,7 @@ class ExpressionStatement(Generable):
         self.expr = expr
 
     def generate(self):
-        yield str(self.text)+";"
+        yield str(self.expr)+";"
 
     mapper_method = "map_expression_statement"
 
